// $Id: Application.cpp,v 1.74 2014/03/11 22:10:30 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Application.h"
#include "Application.moc"

#include "ConfigurationDialog.h"
#include "MainWindow.h"
#include "QtUtil.h"
#include "ScratchFileMonitor.h"
#include "Util.h"

#include <QApplication>

//____________________________________________
Application::Application( CommandLineArguments arguments ) :
    BaseApplication( 0, arguments ),
    Counter( "Application" ),
    mainWindow_(0)
{
    Debug::Throw( "Application::Application.\n" );
    connect( this, SIGNAL(configurationChanged()), SLOT(_updateConfiguration()) );
}

//____________________________________________
Application::~Application( void )
{}

//____________________________________________
bool Application::realizeWidget( void )
{
    Debug::Throw( "Application::realizeWidget.\n" );

    const CommandLineParser parser( commandLineParser( _arguments() ) );
    if( parser.hasOption( "--user" ) )
    { XmlOptions::get().add( "USER_NAME", Option( parser.option( "--user" ), Option::Recordable|Option::Current  ) ); }

    // check if the method has already been called.
    if( !BaseApplication::realizeWidget() ) return false;

    // main window
    mainWindow_ = new MainWindow();
    mainWindow_->setWindowTitle( "Gridwatch" );

    // scratch files
    scratchFileMonitor_ = new ScratchFileMonitor( this );
    connect( qApp, SIGNAL(aboutToQuit()), scratchFileMonitor_, SLOT(deleteScratchFiles()) );
    connect( mainWindow_, SIGNAL(scratchFileCreated(File)), scratchFileMonitor_, SLOT(add(File)) );

    // top widget
    mainWindow_->centerOnDesktop();
    mainWindow_->show();

    // configuration
    emit configurationChanged();

    Debug::Throw( "Application::realizeWidget - done.\n" );
    return true;

}

//____________________________________________
CommandLineParser Application::commandLineParser( CommandLineArguments arguments, bool ignoreWarnings ) const
{
    Debug::Throw( "Application::commandLineParser.\n" );
    CommandLineParser out( BaseApplication::commandLineParser() );
    out.setGroup( CommandLineParser::applicationGroupName );
    out.registerOption( CommandLineParser::Tag( "--user", "-u" ), "string", "user name from whom jobs will be shown" );
    if( !arguments.isEmpty() ) out.parse( arguments, ignoreWarnings );
    return out;

}

//____________________________________________
void Application::usage( void ) const
{
    _usage( "gridwatch" );
    commandLineParser().usage();
    return;
}

//_______________________________________________
void Application::_configuration( void )
{

    Debug::Throw( "Application::_configuration.\n" );
    emit saveConfiguration();
    ConfigurationDialog dialog;
    connect( &dialog, SIGNAL(configurationChanged()), SIGNAL(configurationChanged()) );
    dialog.centerOnWidget( qApp->activeWindow() );
    dialog.toggleSticky( false );
    dialog.exec();

}

//________________________________________________
bool Application::_processCommand( Server::ServerCommand command )
{

    Debug::Throw( "Application::_processCommand.\n" );
    if( BaseApplication::_processCommand( command ) ) return true;
    if( command.command() == Server::ServerCommand::Raise )
    {
        mainWindow_->uniconify();
        return true;
    } else return false;

}
