#ifndef JobStatistics_h
#define JobStatistics_h

// $Id: JobStatistics.h,v 1.14 2014/09/12 08:43:12 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"
#include "TimeStamp.h"

#include <QString>
#include <QVector>

class JobSet;

//! job statistics container
class JobStatistics: public Counter
{
    public:

    //! allows fast, keyed access to any data field
    enum FieldType
    {
        Total,
        Completed,
        Failed,
        Running,
        Pending,
        Unknown,
        nFields
    };

    //! initialize field names
    static void installFields( void );

    //! get field name
    static const QString& fieldName( int index )
    { return _fieldNames()[index]; }

    //! constructor
    JobStatistics( const QString& user = QString() );

    //! constructor from Job list
    JobStatistics( const JobSet& );

    //! equal to operator
    bool operator == (const JobStatistics& stat ) const;

    //! equal to operator
    bool operator != (const JobStatistics& stat ) const
    { return !( *this == stat ); }

    //!@name accessors
    //@{

    const QString& user( void ) const { return user_; }
    const TimeStamp& time( void ) const { return time_; }
    int get( int type ) const { return fields_[type]; }

    //@}

    //!@name modifiers
    //@{
    void setUser( const QString& value ) { user_ = value; }
    void setTime( const TimeStamp& value ) { time_ = value; }
    void set( FieldType type, int value ) { fields_[type] = value; }
    //@}

    protected:

    //! fields
    using FieldNameVector = QVector<QString>;

    //! field names
    static FieldNameVector& _fieldNames( void );

    //! set xml_field name for given index
    static void _setFieldName( FieldType index, const QString& value )
    { _fieldNames()[index] = value; }

    private:

    //! time stamp
    TimeStamp time_;

    //! fields
    using FieldVector = QVector<int>;

    //! fields
    FieldVector fields_;

    //! user
    QString user_;

};

#endif
