#ifndef OpenFileDialog_h
#define OpenFileDialog_h

// $Id: OpenFileDialog.h,v 1.7 2014/02/10 10:34:30 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CustomDialog.h"

#include <QRadioButton>

class CustomComboBox;

class OpenFileDialog: public CustomDialog
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    enum Command
    {
        OpenWith = 1<<0,
        SaveAs = 1<<1,
        Any = OpenWith|SaveAs
    };

    Q_DECLARE_FLAGS( Commands, Command )

    //! constructor
    OpenFileDialog( QWidget*, Commands = Any );

    //! destructor
    virtual ~OpenFileDialog( void )
    {}

    //! set command
    void setCommand( const Command& command )
    { openWithRadioButton_->setChecked( command == OpenWith ); }

    //! return command
    Command command( void )
    { return openWithRadioButton_->isChecked() ? OpenWith : SaveAs; }

    //! combo box
    CustomComboBox& actionComboBox( void ) const
    { return *actionComboBox_; }

    protected Q_SLOTS:

    //! select action from fileSelection dialog.
    void _browse( void );

    private:

    CustomComboBox* actionComboBox_;

    QRadioButton* openWithRadioButton_;
    QRadioButton* saveAsRadioButton_;

};

Q_DECLARE_OPERATORS_FOR_FLAGS( OpenFileDialog::Commands )

#endif
