// $Id: SummaryFrame.cpp,v 1.28 2015/01/08 14:48:59 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/
#include "SummaryFrame.h"
#include "SummaryFrame.moc"

#include "Debug.h"
#include "File.h"
#include "GridLayout.h"
#include "GridLayoutItem.h"
#include "SummaryBar.h"
#include "Util.h"
#include "XmlOptions.h"

//____________________________________________________________
SummaryFrame::SummaryFrame( QWidget* parent ):
    DockPanel( parent )
{

    Debug::Throw( "SummaryFrame::SummaryFrame.\n" );

    // title
    setTitle( "Summary" );
    setOptionName( "SUMMARY_FRAME" );

    GridLayout* gridLayout = new GridLayout();
    gridLayout->setMargin(0);
    gridLayout->setSpacing( 5 );
    gridLayout->setMaxCount( 2 );

    panel().layout()->addItem( gridLayout );

    ( totalJobs_ = new GridLayoutItem( &panel(), gridLayout ) )->setKey( tr( "Total:" ) );
    ( completedJobs_ = new GridLayoutItem( &panel(), gridLayout ) )->setKey( tr( "Completed:" ) );
    ( failedJobs_ = new GridLayoutItem( &panel(), gridLayout ) )->setKey( tr( "Failed:" ) );
    ( runningJobs_ = new GridLayoutItem( &panel(), gridLayout ) )->setKey( tr( "Running:" ) );
    ( pendingJobs_ = new GridLayoutItem( &panel(), gridLayout ) )->setKey( tr( "Waiting:" ) );
    ( unknownJobs_ = new GridLayoutItem( &panel(), gridLayout ) )->setKey( tr( "Unknown:" ) );
    ( updated_ = new GridLayoutItem( &panel(), gridLayout ) )->setKey( tr( "Updated:" ) );

    updated_->setText( TimeStamp::now().toString( TimeStamp::TimeLong ) );

    gridLayout->addWidget( summaryBar_ = new SummaryBar( &panel() ), 8, 0, 1, 2 );

    // hide everything
    _updateJobStatistics( JobStatistics(), false );

}

//____________________________________________________________
void SummaryFrame::setUser( const QString& user )
{
    Debug::Throw( "SummaryFrame::setUser.\n" );
    if( user == userName_ ) return;
    userName_ = user;

    QString host( Util::host( true ) );
    if( host == "localhost" ) setTitle( user );
    else setTitle( QString( "%1 [%2]" ).arg( user ).arg( host ) );

    clear();
}

//____________________________________________________________
void SummaryFrame::_set( GridLayoutItem* item, int value ) const
{ item->setText( value ? QString::number( value ):QString() ); }

//____________________________________________________________
void SummaryFrame::_updateJobStatistics( const JobStatistics& statistics, bool updateStamp )
{

    Debug::Throw( "SummaryFrame::_updateJobStatistics.\n" );

    _set( totalJobs_, statistics.get( JobStatistics::Total ) );
    _set( pendingJobs_, statistics.get( JobStatistics::Pending ) );
    _set( runningJobs_, statistics.get( JobStatistics::Running ) );
    _set( failedJobs_, statistics.get( JobStatistics::Failed ) );
    _set( completedJobs_, statistics.get( JobStatistics::Completed ) );
    _set( unknownJobs_, statistics.get( JobStatistics::Unknown ) );
    if( updateStamp ) updated_->setText( statistics.time().toString( TimeStamp::TimeLong ) );
    summaryBar_->updateJobStatistics( statistics );

    summary_ = QString();
    if( statistics.get( JobStatistics::Total ) > 0 ) summary_ += QString( tr( "Total: %1 " ) ).arg( statistics.get( JobStatistics::Total ) );
    if( statistics.get( JobStatistics::Completed ) > 0 ) summary_ += QString( tr( "Completed: %1 " ) ).arg( statistics.get( JobStatistics::Completed ) );
    if( statistics.get( JobStatistics::Failed ) > 0 ) summary_ += QString( tr( "Failed: %1 " ) ).arg( statistics.get( JobStatistics::Failed ) );
    if( statistics.get( JobStatistics::Running ) > 0 ) summary_ += QString( tr( "Running: %1 " ) ).arg( statistics.get( JobStatistics::Running ) );

    panel().adjustSize();
    if( isDetached() ) panel().window()->adjustSize();

}
